# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html


import sys
from pathlib import Path

## Make sure aputils is in sys.path
docpath = Path(__file__).resolve().parent
sys.path.insert(0, str(docpath.parent))

## Get the major and minor Python version numbers to link to the proper documentation for Python classes
pyversion = '.'.join(str(v) for v in sys.version_info[:2])


# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'Izalia\'s PythonSDK Mods'
copyright = '2022, Izalia Mae'
author = 'Izalia Mae'
release = '1.0'


# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
	'sphinx.ext.autodoc',
	'sphinx.ext.intersphinx',
	'sphinx.ext.viewcode',
	'sphinx_external_toc'
]

autodoc_typehints = "description"
autodoc_class_signature = "separated"
autodoc_member_order = "bysource"

external_toc_path = str(docpath.joinpath('toc.yml'))
external_toc_exclude_missing = True

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', '.pyvenv']
intersphinx_mapping = {
	'python': (f'https://docs.python.org/{pyversion}', None)
}

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

#html_theme = 'sphinx_rtd_theme'
html_theme = 'furo'
html_static_path = ['_static']
# latex_elements = {
# 	'papersize': 'letterpaper',
# 	'pointsize': '10pt',
# 	'preamble': '',
# 	'figure_align': 'htbp'
# }
